##
##  luacheck.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2024 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         luacheck
Summary:      Lua Language Linter
URL:          https://github.com/lunarmodules/luacheck
Vendor:       Peter Melnichenko
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Language
License:      MIT
Version:      1.2.0
Release:      20240714

#   list of sources
Source0:      https://github.com/lunarmodules/luacheck/archive/refs/tags/v%{version}.tar.gz

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101, lua
BuildPreReq:  lua-argparse, lua-lfs
PreReq:       lua-argparse, lua-lfs

%description
    Luacheck is a static analyzer and a linter for Lua. Luacheck detects
    various issues such as usage of undefined global variables, unused
    variables and values, accessing uninitialized variables, unreachable
    code and more. Most aspects of checking are configurable: there are
    options for defining custom project-related globals, for selecting
    set of standard globals (version of Lua standard library), for
    filtering warnings by type and name of related variable, etc. The
    options can be used on the command line, put into a config or
    directly into checked files as Lua comments.

%track
    prog luacheck = {
        version   = %{version}
        url       = https://github.com/lunarmodules/luacheck/releases
        regex     = (__VER__)\.tar\.gz
    }

%prep
    %setup -q

%build

%install
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/bin \
        $RPM_BUILD_ROOT%{l_prefix}/lib/lua/5.4/luacheck
    ( echo "#!%{l_prefix}/bin/lua"
      echo "require \"luacheck.main\""
    ) >luacheck.sh
    %{l_shtool} install -c -m 755 \
        luacheck.sh $RPM_BUILD_ROOT%{l_prefix}/bin/luacheck
    cp -rp src/luacheck \
        $RPM_BUILD_ROOT%{l_prefix}/lib/lua/5.4/
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

